==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PageChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PageChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PageChangedEventArgsDescription, _super);
    function PageChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = 0;
        _this.h = null;
        return _this;
    }
    PageChangedEventArgsDescription.prototype.get_type = function () {
        return "PageChangedEventArgs";
    };
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "page", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Page");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "dataRef", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("DataRef");
        },
        enumerable: true,
        configurable: true
    });
    PageChangedEventArgsDescription.$t = markType(PageChangedEventArgsDescription, 'PageChangedEventArgsDescription', Description.$);
    return PageChangedEventArgsDescription;
}(Description));
export { PageChangedEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/PageChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PageChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PageChangedEventArgsDescription, _super);
    function PageChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = 0;
        _this.j = null;
        return _this;
    }
    PageChangedEventArgsDescription.prototype.get_type = function () {
        return "PageChangedEventArgs";
    };
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "page", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Page");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PageChangedEventArgsDescription.prototype, "dataRef", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("DataRef");
        },
        enumerable: false,
        configurable: true
    });
    PageChangedEventArgsDescription.$t = markType(PageChangedEventArgsDescription, 'PageChangedEventArgsDescription', Description.$);
    return PageChangedEventArgsDescription;
}(Description));
export { PageChangedEventArgsDescription };
